@@ -5,6 +5,7 @@ use utf8;
 use File::pushd;
 use File::Spec;
 use File::Basename;
+use ExtUtils::Manifest 1.54 qw(maniskip);
 
 use Minilla::Git;
 
@@ -35,6 +36,10 @@ sub gather_files {
         }
     }
 
+    if (-f 'MANIFEST.SKIP') {
+        my $skip = maniskip('MANIFEST.SKIP') ;
+        @files = grep { !$skip->($_) } @files;
+    }
     unless ($self->include_dotfiles) {
         @files = grep { basename($_) !~ qr/^\./ } @files;
     }
